@@ -44,7 +44,7 @@ odd_dates %>%
   add_days(2)
 
 ## -----------------------------------------------------------------------------
-x <- zoned_time_parse_complete("1970-04-26 01:30:00-05:00[America/New_York]")
+x <- zoned_time_parse_complete("1970-04-26T01:30:00-05:00[America/New_York]")
 x
 
 ## ---- error=TRUE--------------------------------------------------------------
@@ -148,7 +148,7 @@ year_2050 + five_microseconds
 
 ## -----------------------------------------------------------------------------
 naive_time_parse(
-  c("2019-01-01 01:00:00.1", "2019-01-01 01:00:00.3"), 
+  c("2019-01-01T01:00:00.1", "2019-01-01T01:00:00.3"), 
   precision = "millisecond"
 ) %>%
   as_zoned_time("America/New_York")
