@@ -628,7 +628,7 @@ std::ostringstream&
 ymwdh::stream(std::ostringstream& os, r_ssize i) const NOEXCEPT
 {
   ymwd::stream(os, i);
-  os << ' ';
+  os << 'T';
   rclock::detail::stream_hour(os, hour_[i]);
   return os;
 }
